@@ -1,8 +1,8 @@
 import logging
 import threading
 import requests
-import six
 import json  # noqa # pylint: disable=W0611
+import urllib
 
 from requests import Session
 from requests.adapters import HTTPAdapter
@@ -32,10 +32,10 @@ class RequestsRequestHandler(BaseRequestHandler):
     def __init__(self, pubnub):
         self.session = Session()
 
-        self.session.mount('http://ps.pndsn.com', HTTPAdapter(max_retries=1, pool_maxsize=500))
-        self.session.mount('https://ps.pndsn.com', HTTPAdapter(max_retries=1, pool_maxsize=500))
-        self.session.mount('http://ps.pndsn.com/v2/subscribe', HTTPAdapter(pool_maxsize=500))
-        self.session.mount('https://ps.pndsn.com/v2/subscribe', HTTPAdapter(pool_maxsize=500))
+        self.session.mount('http://%s' % pubnub.config.origin, HTTPAdapter(max_retries=1, pool_maxsize=500))
+        self.session.mount('https://%s' % pubnub.config.origin, HTTPAdapter(max_retries=1, pool_maxsize=500))
+        self.session.mount('http://%s/v2/subscribe' % pubnub.config.origin, HTTPAdapter(pool_maxsize=500))
+        self.session.mount('https://%s/v2/subscribe' % pubnub.config.origin, HTTPAdapter(pool_maxsize=500))
 
         self.pubnub = pubnub
 
@@ -153,8 +153,8 @@ class RequestsRequestHandler(BaseRequestHandler):
                     exception=e))
 
         if res is not None:
-            url = six.moves.urllib.parse.urlparse(res.url)
-            query = six.moves.urllib.parse.parse_qs(url.query)
+            url = urllib.parse.urlparse(res.url)
+            query = urllib.parse.parse_qs(url.query)
             uuid = None
             auth_key = None
 
